import React, { useState } from 'react';
import { Alert, Checkbox } from 'antd';
import { login } from '@/services/user/api';
import { AUTHORITY, BASENAME, USER_MODE } from '@/utils/constants';
import LoginForm from './components/Login';
import styles from './style.less';
import { setAuthority } from '@/utils/authority';
const { UserName, Password, Submit } = LoginForm;

const LoginMessage = ({ content }) => (
  <Alert
    style={{
      marginBottom: 24,
    }}
    message={content}
    type="error"
    showIcon
  />
);

const Login = props => {
  const { userLogin = {}, submitting } = props;
  const { status, type: loginType } = userLogin;
  const [autoLogin, setAutoLogin] = useState(true);
  const [type, setType] = useState('account');
  const handleSubmit = values => {
    /* eslint-disable no-console */
    console.log(values); // eg:{userName: "123", password: "123"}
    const { userName: loginName, password } = values;
    login({ loginName, password }).then(result => {
      console.log(result);
      if (result.success === true && result.pass === true) {
        const { userMode } = result;
        localStorage.setItem('userMode', userMode);
        if (userMode === USER_MODE.ADMIN || userMode === USER_MODE.SUPER) {
          setAuthority([AUTHORITY.LOGIN, AUTHORITY[userMode]]);
          window.location.href = `/${BASENAME}/dbm/dbInit/`;
        }
        if (userMode === USER_MODE.COMMON) {
          setAuthority([AUTHORITY.LOGIN, AUTHORITY.COMMON]);
          window.location.href = `/${BASENAME}/ou/orgList/`;
        }
      } else {
        alert('错误，没有权限');
      }
    });
  };

  return (
    <div className={styles.main}>
      <LoginForm activeKey={type} onTabChange={setType} onSubmit={handleSubmit}>
        {status === 'error' && loginType === 'account' && !submitting && (
          <LoginMessage content="账户或密码错误（admin/ant.design）" />
        )}
        <UserName
          name="userName"
          placeholder="请输入用户名"
          rules={[
            {
              required: true,
              message: '请输入用户名!',
            },
          ]}
        />
        <Password
          name="password"
          placeholder="请输入密码"
          rules={[
            {
              required: true,
              message: '请输入密码！',
            },
          ]}
        />
        <div>
          <Checkbox
            checked={autoLogin}
            onChange={e => setAutoLogin(e.target.checked)}
          >
            自动登录
          </Checkbox>
          {/* <a
            style={{
              float: 'right',
            }}
          >
            忘记密码
          </a> */}
        </div>
        <Submit loading={submitting}>登录</Submit>
      </LoginForm>
    </div>
  );
};

export default Login;
